import type { OpenId4VciAuthCodeFlowOptions, OpenId4VciCredentialRequestOptions as OpenId4VciRequestCredentialOptions, OpenId4VciTokenRequestOptions as OpenId4VciRequestTokenOptions, OpenId4VciRequestTokenResponse, OpenId4VciResolvedCredentialOffer, OpenId4VciRetrieveAuthorizationCodeUsingPresentationOptions, OpenId4VciSendNotificationOptions } from './OpenId4VciHolderServiceOptions';
import type { OpenId4VpAcceptAuthorizationRequestOptions, ResolveOpenId4VpAuthorizationRequestOptions } from './OpenId4vpHolderServiceOptions';
import { AgentContext, DcqlQueryResult, DcqlService, DifPexCredentialsForRequest, DifPresentationExchangeService } from '@credo-ts/core';
import { OpenId4VciMetadata } from '../shared';
import { OpenId4VciHolderService } from './OpenId4VciHolderService';
import { OpenId4VpHolderService } from './OpenId4vpHolderService';
/**
 * @public
 */
export declare class OpenId4VcHolderApi {
    private agentContext;
    private openId4VciHolderService;
    private openId4VpHolderService;
    private difPresentationExchangeService;
    private dcqlService;
    constructor(agentContext: AgentContext, openId4VciHolderService: OpenId4VciHolderService, openId4VpHolderService: OpenId4VpHolderService, difPresentationExchangeService: DifPresentationExchangeService, dcqlService: DcqlService);
    /**
     * Resolves the authentication request given as URI or JWT to a unified format, and
     * verifies the validity of the request.
     *
     * The resolved request can be accepted with the @see acceptOpenId4VpAuthorizationRequest.
     *
     * If the authorization request uses OpenID4VP and included presentation definitions,
     * a `presentationExchange` property will be defined with credentials that satisfy the
     * incoming request. When `presentationExchange` is present, you MUST supply `presentationExchange`
     * when calling `acceptOpenId4VpAuthorizationRequest` as well.
     *
     * @param request
     * Can be:
     * - JWT
     * - URI containing request or request_uri param
     * - Request payload
     * @returns the resolved and verified authentication request.
     */
    resolveOpenId4VpAuthorizationRequest(request: string | Record<string, unknown>, options?: ResolveOpenId4VpAuthorizationRequestOptions): Promise<import("./OpenId4vpHolderServiceOptions").OpenId4VpResolvedAuthorizationRequest>;
    /**
     * Accepts the authentication request after it has been resolved and verified with {@link resolveOpenId4VpAuthorizationRequest}.
     *
     * If the resolved authorization request included a `presentationExchange` property, you MUST supply `presentationExchange`
     * in the `options` parameter. The same is true for `dcql`.
     *
     * For response mode of `direct_post` or `direct_post.jwt` the response will be submitted directly
     * to the response url. For `dc_api` and `dc_api.jwt` the response will be returned but without a
     * `serverResponse`, and you have to submit the response yourself.
     */
    acceptOpenId4VpAuthorizationRequest(options: OpenId4VpAcceptAuthorizationRequestOptions): Promise<{
        readonly ok: true;
        readonly authorizationResponse: ({
            vp_token: string | Record<string, any> | Record<string, string | Record<string, any>> | [string | Record<string, any>, ...(string | Record<string, any>)[]];
            presentation_submission?: any;
            access_token?: string | undefined;
            token_type?: string | undefined;
            expires_in?: number | undefined;
            state?: string | undefined;
            refresh_token?: string | undefined;
            id_token?: string | undefined;
        } & {
            [k: string]: unknown;
        } & {
            presentation_submission?: import("@credo-ts/core").DifPresentationExchangeSubmission;
        }) | {
            response: string;
        };
        readonly authorizationResponsePayload: {
            vp_token: string | Record<string, any> | Record<string, string | Record<string, any>> | [string | Record<string, any>, ...(string | Record<string, any>)[]];
            presentation_submission?: any;
            access_token?: string | undefined;
            token_type?: string | undefined;
            expires_in?: number | undefined;
            state?: string | undefined;
            refresh_token?: string | undefined;
            id_token?: string | undefined;
        } & {
            [k: string]: unknown;
        } & {
            presentation_submission?: import("@credo-ts/core").DifPresentationExchangeSubmission;
        };
        readonly serverResponse?: undefined;
        readonly redirectUri?: undefined;
        readonly presentationDuringIssuanceSession?: undefined;
    } | {
        readonly ok: false;
        readonly serverResponse: {
            readonly status: number;
            readonly body: string | Record<string, unknown> | null;
        };
        readonly authorizationResponse: ({
            vp_token: string | Record<string, any> | Record<string, string | Record<string, any>> | [string | Record<string, any>, ...(string | Record<string, any>)[]];
            presentation_submission?: any;
            access_token?: string | undefined;
            token_type?: string | undefined;
            expires_in?: number | undefined;
            state?: string | undefined;
            refresh_token?: string | undefined;
            id_token?: string | undefined;
        } & {
            [k: string]: unknown;
        } & {
            presentation_submission?: import("@credo-ts/core").DifPresentationExchangeSubmission;
        }) | {
            response: string;
        };
        readonly authorizationResponsePayload: {
            vp_token: string | Record<string, any> | Record<string, string | Record<string, any>> | [string | Record<string, any>, ...(string | Record<string, any>)[]];
            presentation_submission?: any;
            access_token?: string | undefined;
            token_type?: string | undefined;
            expires_in?: number | undefined;
            state?: string | undefined;
            refresh_token?: string | undefined;
            id_token?: string | undefined;
        } & {
            [k: string]: unknown;
        } & {
            presentation_submission?: import("@credo-ts/core").DifPresentationExchangeSubmission;
        };
        readonly redirectUri?: undefined;
        readonly presentationDuringIssuanceSession?: undefined;
    } | {
        readonly ok: true;
        readonly serverResponse: {
            readonly status: number;
            readonly body: Record<string, unknown>;
        };
        readonly authorizationResponse: ({
            vp_token: string | Record<string, any> | Record<string, string | Record<string, any>> | [string | Record<string, any>, ...(string | Record<string, any>)[]];
            presentation_submission?: any;
            access_token?: string | undefined;
            token_type?: string | undefined;
            expires_in?: number | undefined;
            state?: string | undefined;
            refresh_token?: string | undefined;
            id_token?: string | undefined;
        } & {
            [k: string]: unknown;
        } & {
            presentation_submission?: import("@credo-ts/core").DifPresentationExchangeSubmission;
        }) | {
            response: string;
        };
        readonly authorizationResponsePayload: {
            vp_token: string | Record<string, any> | Record<string, string | Record<string, any>> | [string | Record<string, any>, ...(string | Record<string, any>)[]];
            presentation_submission?: any;
            access_token?: string | undefined;
            token_type?: string | undefined;
            expires_in?: number | undefined;
            state?: string | undefined;
            refresh_token?: string | undefined;
            id_token?: string | undefined;
        } & {
            [k: string]: unknown;
        } & {
            presentation_submission?: import("@credo-ts/core").DifPresentationExchangeSubmission;
        };
        readonly redirectUri: string | undefined;
        readonly presentationDuringIssuanceSession: string | undefined;
    }>;
    /**
     * Automatically select credentials from available credentials for a presentation exchange request. Can be called after calling
     * @see resolveOpenId4VpAuthorizationRequest.
     */
    selectCredentialsForPresentationExchangeRequest(credentialsForRequest: DifPexCredentialsForRequest): import("@credo-ts/core").DifPexInputDescriptorToCredentials;
    /**
     * Automatically select credentials from available credentials for a dcql request. Can be called after calling
     * @see resolveOpenId4VpAuthorizationRequest.
     */
    selectCredentialsForDcqlRequest(dcqlQueryResult: DcqlQueryResult): import("@credo-ts/core").DcqlCredentialsForRequest;
    resolveIssuerMetadata(credentialIssuer: string): Promise<OpenId4VciMetadata>;
    /**
     * Resolves a credential offer given as credential offer URL, or issuance initiation URL,
     * into a unified format with metadata.
     *
     * @param credentialOffer the credential offer to resolve
     * @returns The uniform credential offer payload, the issuer metadata, protocol version, and the offered credentials with metadata.
     */
    resolveCredentialOffer(credentialOffer: string): Promise<OpenId4VciResolvedCredentialOffer>;
    /**
     * This function is to be used to receive an credential in OpenID4VCI using the Authorization Code Flow.
     *
     * Not to be confused with the {@link resolveOpenId4VpAuthorizationRequest}, which is only used for OpenID4VP requests.
     *
     * It will generate an authorization session based on the provided options.
     *
     * There are two possible flows:
     * - Oauth2Redirect: an authorization request URI is returend which can be used to obtain the authorization code.
     *   This needs to be done manually (e.g. by opening a browser window)
     * - PresentationDuringIssuance: an openid4vp presentation request needs to be handled. A oid4vpRequestUri is returned
     *   which can be parsed using `resolveOpenId4VpAuthorizationRequest`. After the presentation session has been completed,
     *   the resulting `presentationDuringIssuanceSession` can be used to obtain an authorization code
     *
     * Authorization to request credentials can only be requested through scopes.
     *
     * @param resolvedCredentialOffer Obtained through @see resolveCredentialOffer
     * @param authCodeFlowOptions
     * @returns The authorization request URI alongside the code verifier and original @param authCodeFlowOptions
     */
    resolveOpenId4VciAuthorizationRequest(resolvedCredentialOffer: OpenId4VciResolvedCredentialOffer, authCodeFlowOptions: OpenId4VciAuthCodeFlowOptions): Promise<import("./OpenId4VciHolderServiceOptions").OpenId4VciResolvedAuthorizationRequest>;
    /**
     * Retrieve an authorization code using an `presentationDuringIssuanceSession`.
     *
     * The authorization code can be exchanged for an `accessToken` @see requestToken
     */
    retrieveAuthorizationCodeUsingPresentation(options: OpenId4VciRetrieveAuthorizationCodeUsingPresentationOptions): Promise<{
        authorizationCode: string;
        dpop: {
            alg: import("@credo-ts/core").JwaSignatureAlgorithm;
            jwk: import("@credo-ts/core").Jwk;
            nonce?: string | undefined;
            signer?: import("@openid4vc/oauth2").JwtSignerJwk | undefined;
        } | undefined;
    }>;
    /**
     * Requests the token to be used for credential requests.
     */
    requestToken(options: OpenId4VciRequestTokenOptions): Promise<OpenId4VciRequestTokenResponse>;
    /**
     * Request a set of credentials from the credential isser.
     * Can be used with both the pre-authorized code flow and the authorization code flow.
     */
    requestCredentials(options: OpenId4VciRequestCredentialOptions): Promise<{
        credentials: import("./OpenId4VciHolderServiceOptions").OpenId4VciCredentialResponse[];
        dpop: {
            nonce: string | undefined;
            jwk: import("@credo-ts/core").Jwk;
            alg: import("@credo-ts/core").JwaSignatureAlgorithm;
        } | undefined;
        cNonce: string | undefined;
    }>;
    /**
     * Send a notification event to the credential issuer
     */
    sendNotification(options: OpenId4VciSendNotificationOptions): Promise<void>;
}
