import type { AgentContext, DidPurpose, JwaSignatureAlgorithm, Key } from '@credo-ts/core';
import type { JwtSigner, JwtSignerX5c } from '@openid4vc/oauth2';
import type { OpenId4VcJwtIssuer } from './models';
/**
 * Returns the JWA Signature Algorithms that are supported by the wallet.
 *
 * This is an approximation based on the supported key types of the wallet.
 * This is not 100% correct as a supporting a key type does not mean you support
 * all the algorithms for that key type. However, this needs refactoring of the wallet
 * that is planned for the 0.5.0 release.
 */
export declare function getSupportedJwaSignatureAlgorithms(agentContext: AgentContext): JwaSignatureAlgorithm[];
export declare function getKeyFromDid(agentContext: AgentContext, didUrl: string, allowedPurposes?: DidPurpose[]): Promise<Key>;
export declare function requestSignerToJwtIssuer(agentContext: AgentContext, requestSigner: OpenId4VcJwtIssuer): Promise<Exclude<JwtSigner, JwtSignerX5c> | (JwtSignerX5c & {
    issuer: string;
})>;
export declare function getProofTypeFromKey(agentContext: AgentContext, key: Key): string;
export declare function addSecondsToDate(date: Date, seconds: number): Date;
export declare function dateToSeconds(date: Date): number;
export declare function parseIfJson<T>(input: T): T | Record<string, unknown>;
